<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('haaski_lite_enqueue_scripts')) {

	function haaski_lite_enqueue_scripts() {

		wp_dequeue_script('savana-lite-navigation');

		wp_enqueue_style(
			'owl.carousel',
			get_stylesheet_directory_uri() . '/assets/css/owl.carousel.css', 
			array(), '2.3.4'
		);

		wp_enqueue_style(
			'owl.theme.default',
			get_stylesheet_directory_uri() . '/assets/css/owl.theme.default.css', 
			array(), '2.3.4'
		);

		wp_enqueue_style(
			'haaski-lite-owl-theme',
			get_stylesheet_directory_uri() . '/assets/css/haaski.lite.owl.theme.css', 
			array(), '1.0.0'
		);

		wp_enqueue_script(
			'haaski-lite-navigation',
			get_stylesheet_directory_uri() . '/assets/js/navigation.js',
			array('jquery'), 
			'1.0',
			TRUE
		);

		wp_localize_script( 'haaski-lite-navigation', 'accessibleNavigationScreenReaderText', array(
			'expandMain'   => __( 'Open the main menu', 'haaski-lite' ),
			'collapseMain' => __( 'Close the main menu', 'haaski-lite' ),
			'expandChild'   => __( 'expand submenu', 'haaski-lite' ),
			'collapseChild' => __( 'collapse submenu', 'haaski-lite' ),
		));

		wp_enqueue_script(
			'owl.carousel',
			get_stylesheet_directory_uri() . '/assets/js/owl.carousel.js',
			array('jquery'),
			'2.3.4', 
			TRUE
		);

		wp_deregister_style( 'savana-lite-style' );
		wp_deregister_style( 'savana-lite-' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')) );

		wp_enqueue_style( 'haaski-lite-parent-style' , get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'haaski-lite-style' , get_stylesheet_directory_uri() . '/style.css' );

		wp_enqueue_style(
			'haaski-lite-' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')) . '.css',
			array( 'haaski-lite-style' ),
			'1.0.0'
		);
		
		wp_enqueue_script(
			'haaski-lite-script',
			get_stylesheet_directory_uri() . '/assets/js/script.js',
			array('jquery'),
			'1.0.0',
			TRUE
		);

	}

	add_action( 'wp_enqueue_scripts', 'haaski_lite_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('haaski_lite_replace_hooks')) {

	function haaski_lite_replace_hooks() {

		remove_action( 'savana_lite_mobile_menu', 'savana_lite_mobile_menu_function' );
		remove_action( 'savana_lite_slick_slider', 'savana_lite_slick_slider_function');
		remove_action( 'savana_lite_thumbnail', 'savana_lite_thumbnail_function', 10, 2 );
		remove_action( 'savana_lite_before_content', 'savana_lite_before_content_function' );
		remove_action( 'savana_lite_archive_title', 'savana_lite_archive_title_function' );
		remove_action( 'savana_lite_searched_item', 'savana_lite_searched_item_function' );
		
	}

	add_action('init','haaski_lite_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('haaski_lite_theme_setup')) {

	function haaski_lite_theme_setup() {
		
		remove_theme_support('custom-header');
		unregister_nav_menu( 'top-menu' );
		register_nav_menu( 'secondary-menu', esc_attr__( 'Secondary Menu', 'haaski-lite' ) );
		
		load_child_theme_textdomain( 'haaski-lite', get_stylesheet_directory() . '/languages' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/related-post.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/before-content.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/related-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/featured-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/mobile-menu.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/media.php' );

		if ( !get_theme_mod('savana_lite_logo_text_color') )
			set_theme_mod( 'savana_lite_logo_text_color', '#616161' );

		if ( !get_theme_mod('savana_lite_logo_font_size') )
			set_theme_mod( 'savana_lite_logo_font_size', '40px' );

		if ( !get_theme_mod('savana_lite_logo_description_top_margin') )
			set_theme_mod( 'savana_lite_logo_description_top_margin', '10px' );

	}

	add_action( 'after_setup_theme', 'haaski_lite_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('haaski_lite_customize_register')) {

	function haaski_lite_customize_register( $wp_customize ) {

		$wp_customize->remove_section('slideshow_section');
		$wp_customize->remove_section('topmenu_section');
		
		$wp_customize->remove_control('savana_lite_enable_slideshow_overlay');
		$wp_customize->remove_control('savana_lite_enable_topbar');
		$wp_customize->remove_control('savana_lite_sticky_header');
		$wp_customize->remove_control('savana_lite_enable_header_search_form');
		$wp_customize->remove_control('savana_lite_enable_breadcrumb');
		$wp_customize->remove_control('savana_lite_enable_category_title');
		$wp_customize->remove_control('savana_lite_enable_searched_item');

		$wp_customize->add_section('haaski_lite_post_slideshow_section', array(
			'title' => esc_html__( 'Haaski Lite Post Slideshow', 'haaski-lite' ),
			'description' => esc_html__( 'Haaski Lite Post Slideshow', 'haaski-lite' ),
			'priority' => 12,

		));

		$wp_customize->add_setting( 'haaski_lite_post_slideshow_layout', array(
			'default' => 'layout-1',
			'sanitize_callback' => 'haaski_lite_select_sanitize',
		));

		$wp_customize->add_control( 'haaski_lite_post_slideshow_layout' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'haaski_lite_post_slideshow_section',
			'label' => esc_html__('Grid layout','haaski-lite'),
			'description' => esc_html__('Please select one of available layouts for the desktop devices.','haaski-lite'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','haaski-lite'),
			   'layout-1' => esc_html__( 'Layout 1','haaski-lite'),
			   'layout-2' => esc_html__( 'Layout 2','haaski-lite'),
			   'layout-3' => esc_html__( 'Layout 3','haaski-lite'),
			   'layout-4' => esc_html__( 'Layout 4','haaski-lite'),
			),
		));

		$wp_customize->add_setting( 'haaski_lite_featured_posts_items', array(
			'default' => '3',
			'sanitize_callback' => 'haaski_lite_select_sanitize',
		));

		$wp_customize->add_control( 'haaski_lite_featured_posts_items' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'haaski_lite_post_slideshow_section',
			'label' => esc_html__('Slideshow items','haaski-lite'),
			'description' => esc_html__('Please note that, since it is a post grid, each slide contains 4 articles.','haaski-lite'),
			'choices'  => array (
			   '1' => esc_html__( '1 slide with 4 posts','haaski-lite'),
			   '2' => esc_html__( '2 slide with 8 posts','haaski-lite'),
			   '3' => esc_html__( '3 slide with 12 posts','haaski-lite'),
			   '4' => esc_html__( '4 slide with 16 posts','haaski-lite'),
			   '5' => esc_html__( '5 slide with 20 posts','haaski-lite'),
			),
		));
		
		$wp_customize->add_setting( 'haaski_lite_slideshow_dots', array(
			'default' => true,
			'sanitize_callback' => 'haaski_lite_checkbox_sanize',
			'transport'  => 'refresh'
		));
		
		$wp_customize->add_control( 'haaski_lite_slideshow_dots', array(
			'label' => esc_html__( 'Show Dots','haaski-lite'),
			'section' => 'haaski_lite_post_slideshow_section',
			'type' => 'checkbox',
		));

		$wp_customize->add_setting( 'haaski_lite_enable_related_posts', array(
			'default' => 'on',
			'sanitize_callback' => 'haaski_lite_checkbox_sanize',
		));

		$wp_customize->add_control( 'haaski_lite_enable_related_posts' , array(
			'type' => 'checkbox',
			'section' => 'settings_section',
			'label' => esc_html__('Related posts','haaski-lite'),
			'description' => esc_html__('Do you want to display the related posts at the end of each article?','haaski-lite'),
		));

		$wp_customize->add_setting( 'haaski_lite_header_menu_layout', array(
			'default' => 'layout-1',
			'sanitize_callback' => 'haaski_lite_select_sanitize',
		));

		$wp_customize->add_control( 'haaski_lite_header_menu_layout' , array(
			'priority' => 9,
			'type' => 'select',
			'section' => 'layouts_section',
			'label' => esc_html__('Header menu layout','haaski-lite'),
			'description' => esc_html__('Please select one of available layout for the header menu.','haaski-lite'),
			'choices'  => array (
			   'layout-1' => esc_html__( 'Layout 1','haaski-lite'),
			   'layout-2' => esc_html__( 'Layout 2','haaski-lite'),
			),
		));

		function haaski_lite_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}

		function haaski_lite_checkbox_sanize ($input) {

			return $input ? true : false;

		}

	}

	add_action( 'customize_register', 'haaski_lite_customize_register', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* POST ICON */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('haaski_lite_posticon')) {

	function haaski_lite_posticon() {
		
		$html = '';
	
		$icons = array ( 
			'video' => 'fa fa-play' , 
			'gallery' => 'fa fa-camera' , 
			'audio' => 'fa fa-volume-up' , 
			'chat' => 'fa fa-users', 
			'status' => 'fa fa-keyboard-o', 
			'image' => 'fa fa-picture-o' ,
			'quote' => 'fa fa-quote-left', 
			'link' => 'fa fa-external-link', 
			'aside' => 'fa fa-file-text-o', 
		);
	
		if ( get_post_format() ) { 
		
			$html .= '<i class="'.esc_attr($icons[get_post_format()]).'"></i> '; 
			$html .= ucfirst( strtolower( esc_html(get_post_format()) )); 
		
		} else {
		
			$html .= '<i class="fa fa-pencil-square-o"></i> '; 
			$html .= esc_html__( 'Article','haaski-lite'); 
		
		}

		return $html;
	
	}

}

/*-----------------------------------------------------------------------------------*/
/* GET POSTS ON SLIDESHOW */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('haaski_lite_get_posts_on_slideshow')) {

	function haaski_lite_get_posts_on_slideshow() {

		return intval(savana_lite_setting('haaski_lite_featured_posts_items', 3)) * 4;

	}

}

/*-----------------------------------------------------------------------------------*/
/* Exclude featured posts on homepage */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('haaski_lite_exclude_featured_posts_on_home')) {

	function haaski_lite_exclude_featured_posts_on_home(&$query) {
		
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				strstr(savana_lite_setting('haaski_lite_post_slideshow_layout','layout-1'), 'layout' ) == true
			)			
		){ 
	
			$offset = haaski_lite_get_posts_on_slideshow();
			
			$ppp = get_option('posts_per_page');
		
			if ( $query->is_paged ) {
				
				$page_offset = $offset + ( ($query->query_vars['paged']-1) * $ppp );
				$query->set('offset', $page_offset );
		
			}
			else {
				$query->set('offset',$offset);
			}
	
		}
	
	}

	add_action('pre_get_posts', 'haaski_lite_exclude_featured_posts_on_home', 1 );

}

/*-----------------------------------------------------------------------------------*/
/* Adjust offset pagination */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('haaski_lite_adjust_offset_pagination')) {

	function haaski_lite_adjust_offset_pagination($found_posts, $query) {
	
		$offset = haaski_lite_get_posts_on_slideshow();
	
		if ( 
			(
				$query->is_home() && 
				$query->is_main_query() &&
				strstr(savana_lite_setting('haaski_lite_post_slideshow_layout','layout-1'), 'layout' ) == true
			)			
		){ 
			return $found_posts - $offset;
		}
		
		return $found_posts;
	
	}

	add_filter('found_posts', 'haaski_lite_adjust_offset_pagination', 1, 2 );

}

?>
